@@ -1,7 +1,3 @@
-# @param object The texts to be described
-# @param verbose set to \code{FALSE} to suppress printing, for instance
-# if you simply want to assign the output to a \code{data.frame}
-# @param ... additional arguments affecting the summary produced
 #' @rdname summary.corpus 
 #' @method summary character
 #' @export
@@ -15,17 +11,17 @@
 summary.character <- function(object, n = 100, verbose = TRUE, toLower = FALSE, ...) {
     object <- object[1 : min(c(n, length(object)))]
     if (is.null(names(object))) 
-        names(object) <- paste("text", 1:length(object), sep="")
+        names(object) <- paste("text", seq_along(object), sep = "")
     nsents  <- nsentence(object, ...)
     if (toLower) object <- char_tolower(object)
     toks <- tokenize(object, ...)
     ntokens <- ntoken(toks)
     ntypes <- ntype(toks)
-    results <- data.frame(Text=names(object),
-                          Types=ntypes,
-                          Tokens=ntokens,
-                          Sentences=nsents,
-                          row.names=NULL)
+    results <- data.frame(Text = names(object),
+                          Types = ntypes,
+                          Tokens = ntokens,
+                          Sentences = nsents,
+                          row.names = NULL)
     if (verbose) print(results, ...)
     return(invisible(results))
 }
