@@ -36,7 +36,7 @@ NULL
 #'   \item{\code{include}}{do not treat punctuation characters specially, meaning that collocations will include
 #'   punctuation characters as tokens}
 #'   }
-#' @param toLower convert collocations to lower case if \code{TRUE} (default)
+#' @param tolower convert collocations to lower case if \code{TRUE} (default)
 #' @param ... additional parameters passed to \code{\link{tokens}}
 #' @return a collocations class object: a specially classed data.table consisting 
 #'   of collocations, their frequencies, and the computed association measure(s).
@@ -47,32 +47,32 @@ NULL
 #'   Minnesota.
 #' @seealso \link{tokens_ngrams}
 #' @author Kenneth Benoit
+#' @keywords collocations internal
 #' @examples
+#' \dontrun{
 #' txt <- c("This is software testing: looking for (word) pairs!  
 #'          This [is] a software testing again. For.",
 #'          "Here: this is more Software Testing, looking again for word pairs.")
 #' collocations(txt, punctuation = "dontspan") # default
-#' collocations(txt, punctuation = "dontspan", removePunct = TRUE)  # includes "testing looking"
-#' collocations(txt, punctuation = "ignore", removePunct = TRUE)    # same as previous 
-#' collocations(txt, punctuation = "include", removePunct = FALSE)  # keep punctuation as tokens
+#' collocations(txt, punctuation = "dontspan", remove_punct = TRUE)  # includes "testing looking"
+#' collocations(txt, punctuation = "ignore", remove_punct = TRUE)    # same as previous 
+#' collocations(txt, punctuation = "include", remove_punct = FALSE)  # keep punctuation as tokens
 #'
 #' collocations(txt, size = 2:3)
 #' removeFeatures(collocations(txt, size = 2:3), stopwords("english"))
 #' 
 #' collocations("@@textasdata We really, really love the #quanteda package - thanks!!")
 #' collocations("@@textasdata We really, really love the #quanteda package - thanks!!",
-#'               removeTwitter = TRUE)
+#'               remove_twitter = TRUE)
 #' 
-#' collocations(data_char_inaugural[49:57], n = 10)
-#' collocations(data_char_inaugural[49:57], method = "all", n = 10)
-#' collocations(data_char_inaugural[49:57], method = "chi2", size = 3, n = 10)
+#' collocations(data_corpus_inaugural[49:57], n = 10)
+#' collocations(data_corpus_inaugural[49:57], method = "all", n = 10)
+#' collocations(data_corpus_inaugural[49:57], method = "chi2", size = 3, n = 10)
 #' collocations(corpus_subset(data_corpus_inaugural, Year>1980), method = "pmi", size = 3, n = 10)
+#' }
 collocations <- function(x,  method = c("lr", "chi2", "pmi", "dice", "all"), size = 2, 
-                         n = NULL, toLower = TRUE, 
+                         n = NULL, tolower = TRUE, 
                          punctuation = c("dontspan", "ignore", "include"), ...) {
-#     addedArgs <- names(list(...))
-#     if (length(addedArgs) && any(!(addedArgs %in% names(formals(getS3method("tokenize", "character"))))))
-#         warning("Argument", ifelse(length(addedArgs)>1, "s ", " "), addedArgs, " not used.", sep = "", noBreaks. = TRUE)
     UseMethod("collocations")
 }
  
@@ -89,7 +89,7 @@ wLASTGREPpenn <- "-lrb-_.*"
 #' @noRd
 #' @export
 collocations.corpus <- function(x, method = c("lr", "chi2", "pmi", "dice", "all"), size = 2, 
-                                n = NULL, toLower = TRUE, 
+                                n = NULL, tolower = TRUE, 
                                 punctuation = c("dontspan", "ignore", "include"), ...) {
     collocations(texts(x), method = method, size = size, n = n, punctuation = punctuation, ...)
 }
@@ -98,10 +98,10 @@ collocations.corpus <- function(x, method = c("lr", "chi2", "pmi", "dice", "all"
 #' @noRd
 #' @export    
 collocations.character <- function(x, method = c("lr", "chi2", "pmi", "dice", "all"), size = 2, 
-                                   n = NULL, toLower = TRUE, 
+                                   n = NULL, tolower = TRUE, 
                                    punctuation = c("dontspan", "ignore", "include"), ...) {
     method <- match.arg(method)
-    x <- tokens((if (toLower) char_tolower(x) else x), hash = FALSE, ...)
+    x <- tokens((if (tolower) char_tolower(x) else x), ...)
     collocations(x, method = method, size = size , n = n, punctuation = punctuation)
 }
 
@@ -116,7 +116,7 @@ collocations.tokens <- function(x, ...) {
 #' @noRd
 #' @export    
 collocations.tokenizedTexts <- function(x, method = c("lr", "chi2", "pmi", "dice", "all"), size = 2, 
-                                        n = NULL, toLower = FALSE,
+                                        n = NULL, tolower = FALSE,
                                         punctuation = c("dontspan", "ignore", "include"), ...) {
 
     punctuation <- match.arg(punctuation)
@@ -131,12 +131,12 @@ collocations.tokenizedTexts <- function(x, method = c("lr", "chi2", "pmi", "dice
     
     coll <- NULL
     if (2 %in% size)
-        coll <- collocations2(x, method, 2, n, punctuation = punctuation)
+        coll <- collocations_bigram_old(x, method, 2, n, punctuation = punctuation)
     if (3 %in% size) {
         if (is.null(coll)) 
-            coll <- collocations3(x, method, 3, n, punctuation = punctuation, ...)
+            coll <- collocations_trigram_old(x, method, 3, n, punctuation = punctuation, ...)
         else {
-            coll <- rbind(coll, collocations3(x, method, 3, n, punctuation = punctuation, ...))
+            coll <- rbind(coll, collocations_trigram_old(x, method, 3, n, punctuation = punctuation, ...))
             class(coll) <- c("collocations", class(coll))
         }
     }
@@ -146,7 +146,7 @@ collocations.tokenizedTexts <- function(x, method = c("lr", "chi2", "pmi", "dice
 }
 
 
-collocations3 <- function(x, method=c("lr", "chi2", "pmi", "dice", "all"), size=3, n=NULL, 
+collocations_trigram_old <- function(x, method=c("lr", "chi2", "pmi", "dice", "all"), size=3, n=NULL, 
                           punctuation =  c("dontspan", "ignore", "include"), ...) {
     method <- match.arg(method)
     
@@ -185,7 +185,7 @@ collocations3 <- function(x, method=c("lr", "chi2", "pmi", "dice", "all"), size=
     w1Table <- wordpairs[, sum(count), by=w1]
     setnames(w1Table, "V1", "c1")
     setkey(w1Table, w1)
-    # eliminate any duplicates in w1 - see note above in collocations2
+    # eliminate any duplicates in w1 - see note above in collocations_bigram_old
     dups <- which(duplicated(w1Table[,w1]))
     if (length(dups)) {
         catm("  ...NOTE: dropping duplicates in word1:", w1Table[dups, w1], "\n")
@@ -200,7 +200,7 @@ collocations3 <- function(x, method=c("lr", "chi2", "pmi", "dice", "all"), size=
     setnames(w2Table, "V1", "c2")
     setkey(w2Table, w2)
     setkey(allTable, w2)
-    # eliminate any duplicates in w2 - see note above in collocations2
+    # eliminate any duplicates in w2 - see note above in collocations_bigram_old
     dups <- which(duplicated(w2Table[,w2]))
     if (length(dups)) {
         catm("  ...NOTE: dropping duplicates in word2:", w2Table[dups, w2], "\n")
@@ -215,7 +215,7 @@ collocations3 <- function(x, method=c("lr", "chi2", "pmi", "dice", "all"), size=
     setnames(w3Table, "V1", "c3")
     setkey(w3Table, w3)
     setkey(allTable2, w3)
-    # eliminate any duplicates in w3 - see note above in collocations2
+    # eliminate any duplicates in w3 - see note above in collocations_bigram_old
     dups <- which(duplicated(w3Table[,w3]))
     if (length(dups)) {
         catm("  ...NOTE: dropping duplicates in word3:", w3Table[dups, w3], "\n")
@@ -230,7 +230,7 @@ collocations3 <- function(x, method=c("lr", "chi2", "pmi", "dice", "all"), size=
     setnames(w12Table, "V1", "c12")
     setkey(w12Table, w1, w2)
     setkey(allTable3, w1, w2)
-#     # eliminate any duplicates in w3 - see note above in collocations2
+#     # eliminate any duplicates in w3 - see note above in collocations_bigram_old
 #     dups <- which(duplicated(w12Table[, w1, w2]))
 #     if (length(dups)) {
 #         catm("  ...NOTE: dropping duplicates in word1,2: ... \n", w12Table[dups, w1, w2], "\n")
@@ -381,7 +381,7 @@ collocations3 <- function(x, method=c("lr", "chi2", "pmi", "dice", "all"), size=
 
 
 
-collocations2 <- function(x, method=c("lr", "chi2", "pmi", "dice", "all"), 
+collocations_bigram_old <- function(x, method=c("lr", "chi2", "pmi", "dice", "all"), 
                           size=2, n=NULL, 
                           punctuation =  c("dontspan", "ignore", "include"), ...) {
     
@@ -533,19 +533,19 @@ collocations2 <- function(x, method=c("lr", "chi2", "pmi", "dice", "all"),
         df$dice <- allTable2$dice
     }
     
-    #df[, word1 := factor(word1, levels = 1:length(tlevels), labels = tlevels)]
-    #df[, word2 := factor(word2, levels = 1:length(tlevels), labels = tlevels)]
+    #df[, word1 := factor(word1, levels = seq_along(tlevels), labels = tlevels)]
+    #df[, word2 := factor(word2, levels = seq_along(tlevels), labels = tlevels)]
     class(df) <- c("collocations", class(df))
     df[1:ifelse(is.null(n), nrow(df), n), ]
 }
 
-#' check if an object is collocations type
-#' 
-#' Return \code{TRUE} if an object was constructed by \link{collocations}.
-#' @param x any object
-#' @export
-#' @keywords collocations
-is.collocations <- function(x) {
-    class(x)[1] == "collocations" 
-}
+#' #' check if an object is collocations type
+#' #' 
+#' #' Return \code{TRUE} if an object was constructed by \link{collocations}.
+#' #' @param x any object
+#' #' @export
+#' #' @keywords collocations
+#' is.collocations <- function(x) {
+#'     class(x)[1] == "collocations" 
+#' }
 
