@@ -5,22 +5,22 @@
 #' create a document-feature matrix
 #' 
 #' Construct a sparse document-feature matrix, from a character, \link{corpus}, 
-#' or \link{tokens} object.
+#' \link{tokens}, or even other \link{dfm} object.
 #' @param x character, \link{corpus}, \link{tokens}, or \link{dfm} object
 #' @param tolower convert all tokens to lowercase
 #' @param stem if \code{TRUE}, stem words
 #' @param remove a character vector of user-supplied features to ignore, such as
-#'   "stop words".  To access one possible list (from any list you wish), use
-#'   \code{\link{stopwords}()}.  The pattern matching type will be set by
-#'   \code{valuetype}.  For behaviour of \code{remove} with \code{ngrams > 1},
+#'   "stop words".  To access one possible list (from any list you wish), use 
+#'   \code{\link{stopwords}()}.  The pattern matching type will be set by 
+#'   \code{valuetype}.  For behaviour of \code{remove} with \code{ngrams > 1}, 
 #'   see Details.
-#' @param select a user supplied regular expression defining which features to
+#' @param select a user supplied regular expression defining which features to 
 #'   keep, while excluding all others.  This can be used in lieu of a dictionary
-#'   if there are only specific features that a user wishes to keep. To extract
-#'   only Twitter usernames, for example, set \code{select = "@@*"} and make
-#'   sure that \code{removeTwitter = FALSE} as an additional argument passed to
+#'   if there are only specific features that a user wishes to keep. To extract 
+#'   only Twitter usernames, for example, set \code{select = "@@*"} and make 
+#'   sure that \code{remove_twitter = FALSE} as an additional argument passed to 
 #'   \link{tokenize}.  Note: \code{select = "^@@\\\w+\\\b"} would be the regular
-#'   expression version of this matching pattern.  The pattern matching type
+#'   expression version of this matching pattern.  The pattern matching type 
 #'   will be set by \code{valuetype}.
 #' @param dictionary A list of character vector dictionary entries, including 
 #'   regular expressions (see examples)
@@ -31,20 +31,19 @@
 #'   that this was not a type found in the text, but rather the label of a 
 #'   thesaurus key.  For more fine-grained control over this and other aspects 
 #'   of converting features into dictionary/thesaurus keys from pattern matches 
-#'   to values, you can use \code{\link{dfm_lookup}} after creating the 
-#'   dfm.
+#'   to values, you can use \code{\link{dfm_lookup}} after creating the dfm.
 #' @inheritParams valuetype
 #' @param groups character vector containing the names of document variables for
 #'   aggregating documents; only applies when calling dfm on a corpus object. 
-#'   When \code{x} is a \link{dfm} object, \code{groups} provides a convenient
-#'   and fast method of combining and refactoring the documents of the dfm
+#'   When \code{x} is a \link{dfm} object, \code{groups} provides a convenient 
+#'   and fast method of combining and refactoring the documents of the dfm 
 #'   according to the groups.
 #' @param verbose display messages if \code{TRUE}
-#' @param ... additional arguments passed to \link{tokens}, for character and
+#' @param ... additional arguments passed to \link{tokens}, for character and 
 #'   corpus
-#' @details The default behavior for \code{remove}/\code{select} when
-#'   constructing ngrams using \code{dfm(x, } \emph{ngrams > 1}\code{)} is to
-#'   remove/select any ngram constructed from a matching feature.  If you wish
+#' @details The default behavior for \code{remove}/\code{select} when 
+#'   constructing ngrams using \code{dfm(x, } \emph{ngrams > 1}\code{)} is to 
+#'   remove/select any ngram constructed from a matching feature.  If you wish 
 #'   to remove these before constructing ngrams, you will need to first tokenize
 #'   the texts with ngrams, then remove the features to be ignored, and then 
 #'   construct the dfm using this modified tokenization object.  See the code 
@@ -57,7 +56,6 @@
 #' @seealso  \code{\link{dfm_select}}, \link{dfm-class}
 #' @examples
 #' ## for a corpus
-#' 
 #' corpus_post80inaug <- corpus_subset(data_corpus_inaugural, Year > 1980)
 #' dfm(corpus_post80inaug)
 #' dfm(corpus_post80inaug, tolower = FALSE)
@@ -80,13 +78,6 @@
 #'                country = "states"))
 #' dfm(corpus_post1900inaug, dictionary = mydict)
 #' 
-#' # with the thesaurus feature
-#' mytexts <- c("The new law included a capital gains tax, and an inheritance tax.",
-#'              "New York City has raised a taxes: an income tax and a sales tax.")
-#' mydict <- dictionary(list(tax=c("tax", "income tax", "capital gains tax", "inheritance tax")))
-#' dfm(phrasetotoken(mytexts, mydict), thesaurus = lapply(mydict, function(x) gsub("\\s", "_", x)))
-#' # pick up "taxes" with "tax" as a regex
-#' dfm(phrasetotoken(mytexts, mydict), thesaurus = list(anytax = "tax"), valuetype = "regex")
 #' 
 #' # removing stopwords
 #' testText <- "The quick brown fox named Seamus jumps over the lazy dog also named Seamus, with
@@ -95,11 +86,11 @@
 #' # note: "also" is not in the default stopwords("english")
 #' featnames(dfm(testCorpus, select = stopwords("english")))
 #' # for ngrams
-#' featnames(dfm(testCorpus, ngrams = 2, select = stopwords("english"), removePunct = TRUE))
-#' featnames(dfm(testCorpus, ngrams = 1:2, select = stopwords("english"), removePunct = TRUE))
+#' featnames(dfm(testCorpus, ngrams = 2, select = stopwords("english"), remove_punct = TRUE))
+#' featnames(dfm(testCorpus, ngrams = 1:2, select = stopwords("english"), remove_punct = TRUE))
 #' 
-#' ## removing stopwords before constructing ngrams
-#' tokensAll <- tokens(char_tolower(testText), removePunct = TRUE)
+#' # removing stopwords before constructing ngrams
+#' tokensAll <- tokens(char_tolower(testText), remove_punct = TRUE)
 #' tokensNoStopwords <- removeFeatures(tokensAll, stopwords("english"))
 #' tokensNgramsNoStopwords <- tokens_ngrams(tokensNoStopwords, 2)
 #' featnames(dfm(tokensNgramsNoStopwords, verbose = FALSE))
@@ -112,8 +103,8 @@
 #' testTweets <- c("My homie @@justinbieber #justinbieber shopping in #LA yesterday #beliebers",
 #'                 "2all the ha8ers including my bro #justinbieber #emabiggestfansjustinbieber",
 #'                 "Justin Bieber #justinbieber #belieber #fetusjustin #EMABiggestFansJustinBieber")
-#' dfm(testTweets, select = "#*", removeTwitter = FALSE)  # keep only hashtags
-#' dfm(testTweets, select = "^#.*$", valuetype = "regex", removeTwitter = FALSE)
+#' dfm(testTweets, select = "#*", remove_twitter = FALSE)  # keep only hashtags
+#' dfm(testTweets, select = "^#.*$", valuetype = "regex", remove_twitter = FALSE)
 #' 
 #' # for a dfm
 #' dfm1 <- dfm(data_corpus_irishbudget2010)
@@ -131,7 +122,8 @@ dfm <- function(x,
                 dictionary = NULL,
                 valuetype = c("glob", "regex", "fixed"), 
                 groups = NULL, 
-                verbose = FALSE, ...) {
+                verbose = quanteda_options("verbose"), 
+                ...) {
 
     UseMethod("dfm")
 }
@@ -149,8 +141,9 @@ dfm.character <- function(x,
                 dictionary = NULL,
                 valuetype = c("glob", "regex", "fixed"), 
                 groups = NULL, 
-                verbose = FALSE, ...) {
-    startTime <- proc.time()
+                verbose = quanteda_options("verbose"), 
+                ...) {
+    start_time <- proc.time()
     valuetype <- match.arg(valuetype)
     
     if (verbose && grepl("^dfm\\.character", sys.calls()[2]))
@@ -162,12 +155,12 @@ dfm.character <- function(x,
     }
     
     if (verbose) catm("   ... tokenizing\n")
-    tokenizedTexts <- tokens(x, ...)
+    temp <- tokens(x, ...)
 
-    dfm(tokenizedTexts, verbose = verbose, tolower = FALSE, stem = stem, 
+    dfm(temp, verbose = verbose, tolower = FALSE, stem = stem, 
         remove = remove, select = select,
         thesaurus = thesaurus, dictionary = dictionary, valuetype = valuetype, 
-        startTime = startTime)
+        start_time = start_time)
 }
 
 
@@ -181,17 +174,25 @@ dfm.corpus <- function(x, tolower = TRUE,
                        dictionary = NULL,
                        valuetype = c("glob", "regex", "fixed"), 
                        groups = NULL, 
-                       verbose = FALSE, ...) {
-    if (verbose) {
+                       verbose = quanteda_options("verbose"), ...) {
+    if (verbose)
         catm("Creating a dfm from a corpus ...\n")
-        if (!is.null(groups)) {
-            groupsLab <- ifelse(is.factor(groups), deparse(substitute(groups)), groups)
+    
+    if (!is.null(groups)) {
+        groupsLab <- ifelse(is.factor(groups), deparse(substitute(groups)), groups)
+        if (verbose) 
             catm("   ... grouping texts by variable", 
                  ifelse(length(groupsLab) == 1, "", "s"), ": ", 
                  paste(groupsLab, collapse=", "), "\n", sep="")
-        }
+        if (verbose) catm("   ... tokenizing grouped texts\n")
+        temp <- tokens(texts(x, groups = groups), ...)
+    } else {
+        if (verbose) catm("   ... tokenizing texts\n")
+        temp <- tokens(x, ...)
     }
-    dfm(texts(x, groups = groups),  tolower = tolower,
+    
+    dfm(temp, 
+        tolower = tolower,
         stem = stem,
         select = select,
         remove = remove,
@@ -214,16 +215,16 @@ dfm.tokenizedTexts <- function(x,
                                dictionary = NULL,
                                valuetype = c("glob", "regex", "fixed"), 
                                groups = NULL, 
-                               verbose = FALSE, ...) {
-    
-    
+                               verbose = quanteda_options("verbose"), 
+                               ...) {
+
     valuetype <- match.arg(valuetype)
     dots <- list(...)
-    if (length(dots) && any(!(names(dots)) %in% c("startTime", "codeType")))
+    if (length(dots) && any(!(names(dots)) %in% c("start_time", names(formals(tokens)))))
         warning("Argument", ifelse(length(dots)>1, "s ", " "), names(dots), " not used.", sep = "", noBreaks. = TRUE)
     
-    startTime <- proc.time()
-    if ("startTime" %in% names(dots)) startTime <- dots$startTime
+    start_time <- proc.time()
+    if ("start_time" %in% names(dots)) start_time <- dots$start_time
     
     if (verbose & stri_startswith_fixed(sys.calls()[2], "dfm.token"))
         catm("Creating a dfm from a", class(x)[1], "object ...\n")
@@ -236,7 +237,7 @@ dfm.tokenizedTexts <- function(x,
     
     # set document names if none
     if (is.null(names(x))) {
-        names(x) <- paste("text", 1:length(x), sep="")
+        names(x) <- paste("text", seq_along(x), sep="")
     } 
     
     # use tokens_lookup for dictionaries with multi-word values otherwise do this later
@@ -254,14 +255,19 @@ dfm.tokenizedTexts <- function(x,
     }
         
     # compile the dfm
-    dfmresult <- compile_dfm(x, verbose = verbose)
+    result <- compile_dfm(x, verbose = verbose)
     
     # copy attributes
-    dfmresult@ngrams <- as.integer(attr(x, "ngrams"))
-    dfmresult@skip <- as.integer(attr(x, "skip"))
-    dfmresult@concatenator <- attr(x, "concatenator")
+    result@ngrams <- as.integer(attr(x, "ngrams"))
+    result@skip <- as.integer(attr(x, "skip"))
+    result@concatenator <- attr(x, "concatenator")
+    result@docvars <- attr(x, "docvars")
     
-    dfm(dfmresult, tolower = FALSE, stem = stem, select = select, remove = remove, thesaurus = thesaurus,
+    if (is.null(result@docvars)) {
+        result@docvars <- data.frame()
+    }
+    
+    dfm(result, tolower = FALSE, stem = stem, select = select, remove = remove, thesaurus = thesaurus,
         dictionary = dictionary, valuetype = valuetype, groups = groups, verbose = verbose, ...)
 }
 
@@ -278,15 +284,16 @@ dfm.dfm <- function(x,
                     dictionary = NULL,
                     valuetype = c("glob", "regex", "fixed"), 
                     groups = NULL, 
-                    verbose = FALSE, ...) {
+                    verbose = quanteda_options("verbose"), 
+                    ...) {
 
     valuetype <- match.arg(valuetype)
     dots <- list(...)
-    if (length(dots) && any(!(names(dots)) %in% c("startTime", "codeType")))
+    if (length(dots) && any(!(names(dots)) %in% c("start_time", names(formals(tokens)))))
         warning("Argument", ifelse(length(dots)>1, "s ", " "), names(dots), " not used.", sep = "", noBreaks. = TRUE)
     
-    startTime <- proc.time()
-    if ("startTime" %in% names(dots)) startTime <- dots$startTime
+    start_time <- proc.time()
+    if ("start_time" %in% names(dots)) start_time <- dots$start_time
     
     if (verbose & stri_startswith_fixed(sys.calls()[2], "dfm.dfm"))
         catm("Creating a dfm from a", class(x)[1], "object ...\n")
@@ -350,9 +357,9 @@ dfm.dfm <- function(x,
         catm("   ... created a", paste(format(dim(x), big.mark=",", trim = TRUE), 
                                        collapse=" x "), 
              "sparse dfm\n   ... complete. \nElapsed time:", 
-             format((proc.time() - startTime)[3], digits = 3),
+             format((proc.time() - start_time)[3], digits = 3),
              "seconds.\n")
-    x
+    return(x)
 }
 
 
