@@ -23,6 +23,7 @@ using namespace std;
 
 namespace quanteda{
     
+    typedef ListOf<IntegerVector> Tokens;
     typedef std::vector<unsigned int> Text;
     typedef std::vector<Text> Texts;
     
@@ -43,18 +44,22 @@ namespace quanteda{
     typedef std::vector<double> DoubleParams;
 #endif    
     
-    inline String join(CharacterVector &tokens_, String &delim_){
+
+    inline String join(CharacterVector &tokens_, 
+                       const String delim_ = " "){
+        
         if (tokens_.size() == 0) return "";
-        String token = tokens_[0];
+        String token_ = tokens_[0];
         for (unsigned int i = 1; i < (unsigned int)tokens_.size(); i++) {
-          token += delim_;
-          token += tokens_[i];
+          token_ += delim_;
+          token_ += tokens_[i];
         }
-        token.set_encoding(CE_UTF8);
-        return token;
+        token_.set_encoding(CE_UTF8);
+        return token_;
     }
     
-    inline std::string join(std::vector< std::string > &tokens, std::string &delim){
+    inline std::string join(std::vector<std::string> &tokens, 
+                            const std::string delim = " "){
         if (tokens.size() == 0) return "";
         std::string token = tokens[0];
         for (std::size_t i = 1; i < tokens.size(); i++) {
@@ -62,12 +67,32 @@ namespace quanteda{
         }
         return token;
     }
-
+    
+    inline String join(std::vector<unsigned int> &tokens, 
+                       CharacterVector types_, 
+                       const String delim_ = " ") {
+        
+        String token_("");
+        if (tokens.size() > 0) {
+            if (tokens[0] != 0) {
+                token_ += types_[tokens[0] - 1];
+            }
+            for (std::size_t j = 1; j < tokens.size(); j++) {
+                if (tokens[j] != 0) {
+                    token_ += delim_;
+                    token_ += types_[tokens[j] - 1];
+                }
+            }
+            token_.set_encoding(CE_UTF8);
+        }
+        return token_;
+    }
+    
     inline bool has_na(IntegerVector vec_) {
         for (unsigned int i = 0; i < (unsigned int)vec_.size(); ++i) {
             if (vec_[i] == NA_INTEGER) return true;
         }
-       return false;
+        return false;
     }
     
     /* 
@@ -140,6 +165,42 @@ namespace quanteda{
     typedef std::unordered_set<unsigned int> SetUnigrams;
 #endif    
 
+    inline std::vector<std::size_t> register_ngrams(List words_, SetNgrams &set_words) {
+        std::vector<std::size_t> spans(words_.size());
+        for (unsigned int g = 0; g < (unsigned int)words_.size(); g++) {
+            if (has_na(words_[g])) continue;
+            Ngram word = words_[g];
+            set_words.insert(word);
+            spans[g] = word.size();
+        }
+        sort(spans.begin(), spans.end());
+        spans.erase(unique(spans.begin(), spans.end()), spans.end());
+        std::reverse(std::begin(spans), std::end(spans));
+        return spans;
+    }
+
+    inline std::vector<std::size_t> register_ngrams(List words_, IntegerVector ids_, MapNgrams &map_words) {
+        std::vector<std::size_t> spans(words_.size());
+        for (unsigned int g = 0; g < (unsigned int)words_.size(); g++) {
+            if (has_na(words_[g])) continue;
+            Ngram word = words_[g];
+            map_words[word] = ids_[g];
+            spans[g] = word.size();
+        }
+        sort(spans.begin(), spans.end());
+        spans.erase(unique(spans.begin(), spans.end()), spans.end());
+        std::reverse(std::begin(spans), std::end(spans));
+        return spans;
+    }
+
+// These typedefs are used in fcm_mt, ca, wordfish_mt
+#if QUANTEDA_USE_TBB
+    typedef std::tuple<unsigned int, unsigned int, double> Triplet;
+    typedef tbb::concurrent_vector<Triplet> Triplets;
+#else
+    typedef std::tuple<unsigned int, unsigned int, double> Triplet;
+    typedef std::vector<Triplet> Triplets;
+#endif
 }
 
 #endif
