@@ -30,17 +30,25 @@ test_that("test attr(kwic, 'ntoken') text names", {
     
 test_that("test kwic general", {
     testkwic <- kwic(paste(LETTERS, collapse=' '), 'D')
+    
+    dtf <- data.frame(
+        docname = c('text1'),
+        from = 4L,
+        to = 4L,
+        pre = 'A B C',
+        keyword = 'D',
+        post = 'E F G H I',
+        stringsAsFactors = FALSE)
+    
     expect_equal(
         data.frame(testkwic),
-        data.frame(
-            docname = factor('text1'),
-            # position = "4:4",
-            position = 4,
-            contextPre = ' A B C',
-            keyword = 'D',
-            contextPost = 'E F G H I',
-            stringsAsFactors = FALSE)
-        )
+        dtf)
+    
+    #tokenizedTexts
+    testkwic <- kwic(tokenize(paste(LETTERS, collapse=' ')), 'D')
+    expect_equal(
+        data.frame(testkwic),
+        dtf) 
 })
 
 
@@ -49,12 +57,12 @@ test_that("test kwic on first token", {
     expect_that(
         data.frame(testkwic),
         equals(data.frame(
-            docname = factor('text1'),
-            # position = "1:1",
-            position = 1,
-            contextPre = '',
+            docname = c('text1'),
+            from = 1L,
+            to = 1L,
+            pre = '',
             keyword = 'A',
-            contextPost = 'B C D E F',
+            post = 'B C D E F',
             stringsAsFactors = FALSE
         ))
     )
@@ -66,12 +74,12 @@ test_that("test kwic on last token", {
     expect_that(
         data.frame(testkwic),
         equals(data.frame(
-            docname = factor('text1'),
-            # position = "26:26",
-            position = 26,
-            contextPre = 'U V W X Y',
+            docname = c('text1'),
+            from = 26L,
+            to = 26L,
+            pre = 'U V W X Y',
             keyword = 'Z',
-            contextPost = '',
+            post = '',
             stringsAsFactors = FALSE
         ))
     )
@@ -83,11 +91,12 @@ test_that("test kwic on two tokens", {
     expect_that(
         data.frame(testkwic),
         equals(data.frame(
-            docname = factor('text1'),
-            position = '4:5',
-            contextPre = ' A B C',
+            docname = c('text1'),
+            from = 4L,
+            to = 5L,
+            pre = 'A B C',
             keyword = 'D E',
-            contextPost = 'F G H I J',
+            post = 'F G H I J',
             stringsAsFactors = FALSE
         ))
     )
@@ -95,7 +104,7 @@ test_that("test kwic on two tokens", {
 
 test_that("test kwic on non-existant token", {
     testkwic <- kwic(paste(LETTERS, collapse=' '), 'É')
-    expect_true( is.data.frame(testkwic) )
+    expect_true(is.data.frame(testkwic) )
 })
 
 test_that("test kwic on multiple texts", {
@@ -107,13 +116,13 @@ test_that("test kwic on multiple texts", {
     expect_that(
         data.frame(testkwic),
         equals(data.frame(
-            docname = factor('text2'),
-            # position = "1:1",
-            position = 1,
-            contextPre='',
-            keyword='A',
-            contextPost='B C D E F',
-            stringsAsFactors=FALSE
+            docname = c('text2'),
+            from = 1L,
+            to = 1L,
+            pre = '',
+            keyword = 'A',
+            post = 'B C D E F',
+            stringsAsFactors = FALSE
         ))
     )
 })
@@ -126,13 +135,13 @@ test_that("test kwic with multiple matches", {
     expect_that(
         data.frame(testkwic),
         equals(data.frame(
-            docname = factor(c('text1', 'text1')),
-            # position = c("1:1", "27:27"),
-            position = c(1, 27),
-            contextPre = c('', 'V W X Y Z'),
-            keyword=c('A', 'A'),
-            contextPost=c('B C D E F', 'B C D E F'),
-            stringsAsFactors=F
+            docname = c(c('text1', 'text1')),
+            from = c(1L, 27L),
+            to = c(1L, 27L),
+            pre = c('', 'V W X Y Z'),
+            keyword = c('A', 'A'),
+            post = c('B C D E F', 'B C D E F'),
+            stringsAsFactors = F
         ))
     )
 })
@@ -142,19 +151,19 @@ test_that("test kwic with multiple matches, where one is the last (fixed bug)",
     expect_that(
         data.frame(testkwic),
         equals(data.frame(
-            docname = factor(c('text1', 'text1')),
-            # position = c("4:4", "6:6"),
-            position = c(4, 6),
-            contextPre=c(' what does the', 'what does the fox say'),
-            keyword=c('fox', 'fox'),
-            contextPost=c('say fox ', ''),
-            stringsAsFactors=F
+            docname = c(c('text1', 'text1')),
+            from = c(4L, 6L),
+            to = c(4L, 6L),
+            pre = c('what does the', 'what does the fox say'),
+            keyword = c('fox', 'fox'),
+            post = c('say fox', ''),
+            stringsAsFactors = F
         ))
     )
 })
 
 
-txt <- data_char_inaugural["2005-Bush"]
+txt <- data_corpus_inaugural["2005-Bush"]
 
 test_that("test that kwic works for glob types", {
     kwicGlob <- kwic(txt, "secur*", window = 3, valuetype = "glob", case_insensitive = TRUE)
@@ -187,13 +196,13 @@ test_that("test that kwic works for regex types", {
 })
 
 test_that("test that kwic works for fixed types", {
-    kwicFixed <- kwic(inaugTexts, "security", window = 3, valuetype = "fixed", case_insensitive = TRUE)
+    kwicFixed <- kwic(data_corpus_inaugural, "security", window = 3, valuetype = "fixed", case_insensitive = TRUE)
     expect_true(
         setequal(c("security", "Security"),
                  unique(kwicFixed$keyword))
     )
     
-    kwicFixed <- kwic(inaugTexts, "security", window = 3, valuetype = "fixed", case_insensitive = FALSE)
+    kwicFixed <- kwic(data_corpus_inaugural, "security", window = 3, valuetype = "fixed", case_insensitive = FALSE)
     expect_true(
         setequal(c("security"),
                  unique(kwicFixed$keyword))
@@ -208,18 +217,52 @@ test_that("is.kwic works as expected", {
 
 test_that("textplot_xray works with new kwic, one token phrase", {
     data_corpus_inauguralPost70 <- corpus_subset(data_corpus_inaugural, Year > 1970)
-    knew <- kwic(data_corpus_inauguralPost70, "american", new = TRUE)
-    kold <- kwic(data_corpus_inauguralPost70, "american", new = FALSE)
-    expect_silent(textplot_xray(kold))
+    knew <- kwic(data_corpus_inauguralPost70, "american")
     expect_silent(textplot_xray(knew))
 })
 
 test_that("textplot_xray works with new kwic, two token phrase", {
     data_corpus_inauguralPost70 <- corpus_subset(data_corpus_inaugural, Year > 1970)
     knew <- kwic(data_corpus_inauguralPost70, "american people", new = TRUE)
-    kold <- kwic(data_corpus_inauguralPost70, "american people", new = FALSE)
-    expect_silent(textplot_xray(kold))
     expect_silent(textplot_xray(knew))
 })
 
+test_that("textplot_xray works with new kwic, two token phrase", {
+    data_corpus_inauguralPost70 <- corpus_subset(data_corpus_inaugural, Year > 1970)
+    knew <- kwic(data_corpus_inauguralPost70, "american people", new = TRUE)
+    expect_silent(textplot_xray(knew))
+})
+
+test_that("print method works as expected", {
+    testkwic <- kwic('what does the fox say fox', 'fox')
+    expect_output(print(testkwic), "*\\| fox \\|*")
+    expect_output(print(testkwic), "\\[text1, 4\\]*")
+    
+    testkwic <- kwic('what does the fox say fox', 'foox')
+    expect_null(print(testkwic))
+})
+
+
+test_that("kwic works with padding", {
+    testtoks <- tokens('what does the fox say cat')
+    expect_output(print(kwic(tokens_remove(testtoks, c('what', 'the'), padding = TRUE), 'fox')),
+                  '\\[text1, 4\\]  does \\| fox \\| say cat')
+    expect_null(print(kwic(tokens_remove(testtoks, '*', padding = TRUE), 'fox')))
+    
+})
+
+test_that("as.tokens is working", {
+    testkwic <- kwic('what does the fox say fox', 'fox', window = 1)
+    testtoks <- as.tokens(testkwic)
+    expect_equivalent(as.list(testtoks),
+                      list(c("the", "fox", "say"), c("say", "fox")))
+    
+    testdfm <- dfm(testtoks)
+    expect_equivalent(as.vector(testdfm[1,]),
+                      c(1, 1, 1))
+    expect_equivalent(as.vector(testdfm[2,]),
+                      c(0, 1, 1))
+})
+
+
 
